redisutil

package
v0.0.0-...-3217735 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Aug 14, 2015 License: MIT Imports: 3 Imported by: 1

Documentation

Index

Constants

const (
	ENV_REDIS_SERVER = "REDIS_SERVER"

	SET_COMMAND  = "SET"
	HSET_COMMAND = "HSET"
)

Variables

This section is empty.

Functions

func GetRedisServer

func GetRedisServer() string

GetRedisServer reads the environment variable to return the address of redis.

func GetString

func GetString(key string) string

GetString performs get command to return string.

func WriteLogsToRedis

func WriteLogsToRedis(buildId int64, logs []string) bool

WriteLogsToRedis take the array of log to write to redis.

Types

This section is empty.

Jump to