Documentation
¶
Index ¶
Constants ¶
const ( ENV_REDIS_SERVER = "REDIS_SERVER" SET_COMMAND = "SET" HSET_COMMAND = "HSET" )
Variables ¶
This section is empty.
Functions ¶
func GetRedisServer ¶
func GetRedisServer() string
GetRedisServer reads the environment variable to return the address of redis.
func WriteLogsToRedis ¶
WriteLogsToRedis take the array of log to write to redis.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.